==> zio-aws-route53recoverycontrolconfig_3-5.17.127.1-sources.jar: zio/aws/route53recoverycontrolconfig/model/DescribeRoutingControlRequest.scala <==
package zio.aws.route53recoverycontrolconfig.model
import zio.aws.route53recoverycontrolconfig.model.primitives.__string
import zio.ZIO
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters.*
final case class DescribeRoutingControlRequest(routingControlArn: __string) {
  def buildAwsValue()
      : software.amazon.awssdk.services.route53recoverycontrolconfig.model.DescribeRoutingControlRequest = {
    import DescribeRoutingControlRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.route53recoverycontrolconfig.model.DescribeRoutingControlRequest
      .builder()
      .routingControlArn(__string.unwrap(routingControlArn): java.lang.String)
      .build()
  }
  def asReadOnly
      : zio.aws.route53recoverycontrolconfig.model.DescribeRoutingControlRequest.ReadOnly =
    zio.aws.route53recoverycontrolconfig.model.DescribeRoutingControlRequest
      .wrap(buildAwsValue())
}
object DescribeRoutingControlRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.route53recoverycontrolconfig.model.DescribeRoutingControlRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.route53recoverycontrolconfig.model.DescribeRoutingControlRequest =
      zio.aws.route53recoverycontrolconfig.model
        .DescribeRoutingControlRequest(routingControlArn)
    def routingControlArn: __string
    def getRoutingControlArn: ZIO[Any, Nothing, __string] =
      ZIO.succeed(routingControlArn)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.route53recoverycontrolconfig.model.DescribeRoutingControlRequest
  ) extends zio.aws.route53recoverycontrolconfig.model.DescribeRoutingControlRequest.ReadOnly {
    override val routingControlArn: __string =
      zio.aws.route53recoverycontrolconfig.model.primitives
        .__string(impl.routingControlArn())
  }
  def wrap(
      impl: software.amazon.awssdk.services.route53recoverycontrolconfig.model.DescribeRoutingControlRequest
  ): zio.aws.route53recoverycontrolconfig.model.DescribeRoutingControlRequest.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-route53recoverycontrolconfig_3-5.17.195.1-sources.jar: zio/aws/route53recoverycontrolconfig/model/DescribeRoutingControlRequest.scala <==
package zio.aws.route53recoverycontrolconfig.model
import zio.aws.route53recoverycontrolconfig.model.primitives.__string
import zio.ZIO
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters.*
final case class DescribeRoutingControlRequest(routingControlArn: __string) {
  def buildAwsValue()
      : software.amazon.awssdk.services.route53recoverycontrolconfig.model.DescribeRoutingControlRequest = {
    import DescribeRoutingControlRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.route53recoverycontrolconfig.model.DescribeRoutingControlRequest
      .builder()
      .routingControlArn(routingControlArn: java.lang.String)
      .build()
  }
  def asReadOnly
      : zio.aws.route53recoverycontrolconfig.model.DescribeRoutingControlRequest.ReadOnly =
    zio.aws.route53recoverycontrolconfig.model.DescribeRoutingControlRequest
      .wrap(buildAwsValue())
}
object DescribeRoutingControlRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.route53recoverycontrolconfig.model.DescribeRoutingControlRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.route53recoverycontrolconfig.model.DescribeRoutingControlRequest =
      zio.aws.route53recoverycontrolconfig.model
        .DescribeRoutingControlRequest(routingControlArn)
    def routingControlArn: __string
    def getRoutingControlArn: ZIO[Any, Nothing, __string] =
      ZIO.succeed(routingControlArn)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.route53recoverycontrolconfig.model.DescribeRoutingControlRequest
  ) extends zio.aws.route53recoverycontrolconfig.model.DescribeRoutingControlRequest.ReadOnly {
    override val routingControlArn: __string =
      impl.routingControlArn(): __string
  }
  def wrap(
      impl: software.amazon.awssdk.services.route53recoverycontrolconfig.model.DescribeRoutingControlRequest
  ): zio.aws.route53recoverycontrolconfig.model.DescribeRoutingControlRequest.ReadOnly =
    new Wrapper(impl)
}
